clear
clear matrix
capture log close
set mem 600m
set more off



***** *** Set this global to the file path leading to the folder containing the analysis files
global prices "C:\Users\Hanlon\Dropbox\UK_patents\replication_files\figure_10"


****
global results "$prices\results"


****

insheet using "$prices\economist_price_data.csv", comma names clear


*** Generate quaters
gen quarter=1
replace quarter=2 if obs_month>3
replace quarter=3 if obs_month>6
replace quarter=4 if obs_month>9


rename issue_year year

**** Keep necessary series and collapse to quarterly data
collapse (mean)  upland_mid pernambuco_fair egyptian_fair  surate_fair_complete upland_ordinary, by(year quarter)

sort year quarter

**** Interpolate missing egyptian price values
replace egyptian_fair=(egyptian_fair[_n-1]+egyptian_fair[_n+1])/2 if egyptian_fair==.


*** Construct relative price series
gen rel_pern=pernambuco_fair/upland_mid
gen rel_egypt=egyptian_fair/upland_mid
gen rel_india=surate_fair_complete/upland_ordinary


*** Generate and format date variable
gen date=yq(year, quarter)
format date %tq
order  year quarter date

**** Keep necessary series
keep date year quarter rel_pern rel_egypt rel_india

*** Reshape to wide
reshape long rel_, i(date) j(location) string
replace loc="brazil" if loc=="pern"
rename rel_ relative_price


*** Prepare data
gen loc_code=1
replace loc_code=2 if location=="brazil"
replace loc_code=3 if location=="egypt"
xtset loc_code date, quarterly


*** Location dummy variables
gen india=0
replace india=1 if location=="india"
gen brazil=0
replace brazil=1 if location=="brazil"
gen egypt=0
replace egypt=1 if location=="egypt"


*** Prepare data
xi i.year i.quarter i.location


*** Generate explanatory variables
forval i=1859/1875 {
gen india_`i'=0
replace india_`i'=1 if year==`i' & india==1

}


**** Control for the rebellion years of 1858-1859
gen rebellion=0
replace rebellion=1 if india==1 & year==1858
replace rebellion=1 if india==1 & year==1859



*********************** Regressions *******************************

**** Without rebellion controls
newey relative_price india_* _Iyear* _Iquarter* _Ilocat*, force lag(8)
est store PANEL1


**** With rebellion controls
newey relative_price india_* rebellion _Iyear* _Iquarter* _Ilocat*, force lag(8)
est store PANEL2

outreg2 [PANEL1 PANEL2] using "$results\figure_10_results", tex replace see label drop(_I*)





bob;
