clear
clear matrix
capture log close
set mem 600m
set more off



***** *** Set this global to the file path leading to the folder containing the analysis files
global prices "C:\Users\Hanlon\Dropbox\UK_patents\replication_files\figure_11"


****
global results "$prices\results"


****

insheet using "$prices\economist_price_data.csv", comma names clear


*** Generate quaters
gen quarter=1
replace quarter=2 if obs_month>3
replace quarter=3 if obs_month>6
replace quarter=4 if obs_month>9

rename issue_year year

**** Keep necessary series and collapse to quarterly data
collapse (mean)  upland_mid pernambuco_fair egyptian_fair  surate_fair_complete upland_ordinary, by(year quarter)

sort year quarter

**** Interpolate missing egyptian price values
replace egyptian_fair=(egyptian_fair[_n-1]+egyptian_fair[_n+1])/2 if egyptian_fair==.


*** Construct relative price series
gen rel_pern=pernambuco_fair/upland_mid
gen rel_egypt=egyptian_fair/upland_mid
gen rel_india=surate_fair_complete/upland_ordinary


*** Generate and format date variable
gen date=yq(year, quarter)
format date %tq
order  year quarter date


*** Keep only necessary variables
keep date year quarter rel_india 

*** Prepare for regressions
tsset date, quarterly
xi i.year i.quarter


*** Generate explanatory variables
forval i=1859/1875 {
gen india_`i'=0
replace india_`i'=1 if year==`i'

}


**** Control for the rebellion years of 1858-1859
gen rebellion=0
replace rebellion=1 if year==1858
replace rebellion=1 if year==1859

*********************** Regressions *******************************

**** Without rebellion controls
newey rel_india india_*, lag(8)
est store PANEL1

**** With rebellion controls
newey rel_india india_* rebellion, lag(8)
est store PANEL2

outreg2 [PANEL1 PANEL2] using "$results\figure_11_results", tex replace see label drop(_I*)


bob;
