clear
clear matrix
capture log close
set more off
set seed 365476247 
set matsize 4000
postutil clear


*** Set this global to the file path leading to the folder containing the analysis files
global root "C:\Users\Hanlon\Dropbox\UK_patents\replication_files\table_I"


******* Results global
global results "$root\results"


******* Insheet data
use "$root\analysis_data_main", clear

***** Define shock period
gen period=0
replace period=1 if year>1860 & year<1866
replace period=2 if year>1865

***** Collapse annual data to pre-shock, shock, post-shock periods
collapse (mean) pat, by(subcat period)


**** Construct explanatory variables
gen shock=0
replace shock=1 if period==1
gen shock_all=0
replace shock_all=1 if shock==1 & subcat=="gins"
replace shock_all=1 if shock==1 & subcat=="carding_dirt"
replace shock_all=1 if shock==1 & subcat=="openers_cotton"


*** Construct dependent variable
gen log_pat=log(pat)


**** Prepare data
encode subcat, gen(subcat_code)
xtset subcat_code period


**** Label variables
label variable shock_all "India-related x shock period"


************ Regressions ***************
xi i.period

xtreg log_pat shock_all _Iperiod*, fe
matrix alpha=e(b)
matrix beta=alpha[1,1]
matrix drop alpha



quietly {
	forval i =1/20 {
		local ii =`i'+1
		forval j =`ii'/21 {
		local jj=`j'+1
			forval k =`jj'/22 {
				
				gen treat=0
				replace treat=1 if (subcat_code==`i' & period==1)
				replace treat=1 if (subcat_code==`j' & period==1)
				replace treat=1 if (subcat_code==`k' & period==1)
				xtreg log_pat treat _Iperiod*, fe
				matrix alpha=e(b)
				matrix beta=beta\alpha[1,1]
				matrix drop alpha
				drop treat
				
			}
		}
	}
} 

matrix treated=beta[1,1]
matrix permuted=beta[2...,1]

clear
svmat treated
svmat permuted

replace treated=treated[_n-1] if treated==.

gen abs_permuted=abs(permuted)
gsort -abs_permuted
gen test=0
replace test=1 if abs_permuted>=treated

gen test_count=1
collapse(sum) test test_count
gen reject_pr=test/test_count

br

bob;
