clear
clear matrix
capture log close
set mem 800m
set more off


*** Set this global to the file path leading to the folder containing the analysis files
global renewal "C:\Users\Hanlon\Dropbox\UK_patents\replication_files\table_II"

******* Results global
global results "$renewal\results"


**** Load renewal fee data
use "$renewal\renewal_data", clear



***** Define shock period
gen period=0
replace period=1 if year>1860 & year<1866
replace period=2 if year>1865

*** Drop post-shock period
drop if period==2

***** Collapse annual data to pre-shock, shock, post-shock periods
collapse (mean) pat, by(subcat period)


**** Construct explanatory variables
gen shock=0
replace shock=1 if period==1
gen shock_all=0
replace shock_all=1 if shock==1 & subcat=="gins"
replace shock_all=1 if shock==1 & subcat=="carding_dirt"
replace shock_all=1 if shock==1 & subcat=="openers_cotton"

*** Construct dependent variable
gen log_pat=log(pat)


**** Prepare data
encode subcat, gen(subcat_code)
drop subcat
rename subcat_code subcat
xtset subcat period

xi  i.period i.subcat

**** Label variables
label variable shock_all "India-related x shock period"
label variable _Iperiod_1 "Shock period"


********* Main regression results
xtreg log_pat shock_all _Iper* , fe vce(robust)
est store NEW1 

**** Outsheet main regression results
outreg2 [NEW1] using "$results\column2_main_result", tex replace see label noaster drop(_I*)


****** Regression with HC2 standard errors for Imbens & Kolesar p-value
reg log_pat shock_all _Iper* _Isub*, vce(hc2)
global maint=_b[shock_all] / _se[shock_all]


************ Calculate Welch's degrees-of-freedom
preserve
bysort shock_all: egen ybar=mean(log_pat)
gen ydiff=log_pat-ybar
gen ydiff_sq=ydiff*ydiff
gen n=1
collapse (sum) ydiff_sq n, by(shock_all)
gen sigma_sq=ydiff_sq/(n-1)

gen ones=1 
reshape wide ydiff_sq n sigma_sq, i(ones) j(shock_all)

gen kwelch=.
replace kwelch=((sigma_sq0/n0)+(sigma_sq1/n1))^2/((sigma_sq0^2)/((n0-1)*n0^2)+(sigma_sq1^2/((n1-1)*n1^2)))
gen kbm=.
replace kbm=((n0+n1)^2*(n0-1)*(n1-1))/(n1^2*(n1-1)+n0^2*(n0-1))

mkmat kwelch
global kwelch_val=kwelch[1,1]

** Display Welch's DOF
display $kwelch_val

mkmat kbm
global kbm_val=kbm[1,1]
display $kbm_val
restore


**** Display Imbens & Kolesar p-value
local p_value_conser=2*(ttail(($kwelch_val),abs($maint)))
di "P-value from tdistribution with df=2 = `p_value_conser'"

bob;
