clear
clear matrix
capture log close
set mem 800m
set matsize 5000
set more off


*** Set this global to the file path leading to the folder containing the analysis files
global newtons "C:\Users\Hanlon\Dropbox\UK_patents\replication_files\table_II"


**** Load Newton's London Journal data
use "$newtons\newtons_london_journal_data", clear



***** Define shock period
gen period=0
replace period=1 if year>1860 & year<1866


***** Collapse annual data to pre-shock, shock, post-shock periods
collapse (mean) pat, by(subcat period)

**** Prepare data
encode subcat, gen(subcat_code)
xtset subcat_code period

** Drop subcategories with no mentions
drop if subcat=="bobbins"
drop if subcat=="winding_on"


**** Explanatory variables
gen shock_all=0
replace shock_all=1 if period==1 & subcat=="gins"
replace shock_all=1 if period==1 & subcat=="carding_dirt"
replace shock_all=1 if period==1 & subcat=="openers_cotton"


*** Dependent variable
gen log_pat=log(pat)



**** Label variables
label variable shock_all "India-related x shock period"

xi  i.period

************ Regressions ***************


*******************************************************************************
************ Regressions ***************

xtreg log_pat shock_all _Iperiod*, fe
matrix alpha=e(b)
matrix beta=alpha[1,1]
matrix drop alpha



quietly {
	forval i =1/18 {
		local ii =`i'+1
		forval j =`ii'/19 {
		local jj=`j'+1
			forval k =`jj'/20 {
				
				gen treat=0
				replace treat=1 if (subcat_code==`i' & period==1)
				replace treat=1 if (subcat_code==`j' & period==1)
				replace treat=1 if (subcat_code==`k' & period==1)
				xtreg log_pat treat _Iperiod*, fe
				matrix alpha=e(b)
				matrix beta=beta\alpha[1,1]
				matrix drop alpha
				drop treat
				
			}
		}
	}
} 

matrix treated=beta[1,1]
matrix permuted=beta[2...,1]

clear
svmat treated
svmat permuted

replace treated=treated[_n-1] if treated==.

gen abs_permuted=abs(permuted)
gsort -abs_permuted
gen test=0
replace test=1 if abs_permuted>=treated

gen test_count=1
collapse(sum) test test_count
gen reject_pr=test/test_count

br


